@@ -18,7 +18,7 @@ class JciHitachiCommand:
                                00000100000000000000002000010000 \
                                000000000000000002000d278050f0d4 \
                                469dafd3605a6ebbdb130d278052f0d4 \
-                               469dafd3605a6ebbdb13060006010000 \
+                               469dafd3605a6ebbdb13060006000000 \
                                0000")
         self.job_info_base[32:40] = bytearray.fromhex(hex(int(gateway_mac_address))[2:])
     
@@ -45,7 +45,7 @@ class JciHitachiCommand:
 
 
 class JciHitachiCommandAC(JciHitachiCommand):
-    """Sending job command to AC.
+    """Sending job command to air conditioner.
 
     Parameters
     ----------
@@ -74,6 +74,9 @@ class JciHitachiCommandAC(JciHitachiCommand):
 
         job_info = self.job_info_base.copy()
         
+        # Device type
+        job_info[77] = 1
+
         # Command (eg. target_temp)
         job_info[78] = 128 + JciHitachiAC.idx[command]
 
@@ -83,13 +86,110 @@ class JciHitachiCommandAC(JciHitachiCommand):
         # Checksum 
         # Original algorithm:
         # xor job_info 76~80
-        # Since byte 76, 77, and 79 are constants,
+        # Since byte 76(0x06), 77(device type), and 79(0x00) are constants,
         # here is the simplified algorithm:
         # command ^ value ^ 0x07 (flip last 3 bits) 
         job_info[81] = job_info[78] ^ job_info[80] ^ 0x07
 
-        assert len(job_info) == 82, \
-            "The length of job_info should be 82 bytes."
+        return job_info
+
+
+class JciHitachiCommandDH(JciHitachiCommand):
+    """Sending job command to dehumidifier.
+
+    Parameters
+    ----------
+    gateway_mac_address : str
+        Gateway mac address.
+    """
+
+    def __init__(self, gateway_mac_address):
+        super().__init__(gateway_mac_address)
+
+    def get_command(self, command, value):
+        """Get job command.
+
+        Parameters
+        ----------
+        command : str
+            Status name.
+        value : int
+            Status value.
+
+        Returns
+        -------
+        bytearray
+            Bytearray command.
+        """
+
+        job_info = self.job_info_base.copy()
+        
+        # Device type
+        job_info[77] = 4
+
+        # Command (eg. target_temp)
+        job_info[78] = 128 + JciHitachiDH.idx[command]
+
+        # Value (eg. 27)
+        job_info[80] = value
+
+        # Checksum
+        # Original algorithm:
+        # xor job_info 76~80
+        # Since byte 76(0x06), 77(device type), and 79(0x00) are constants,
+        # here is the simplified algorithm:
+        # command ^ value ^ 0x02
+        job_info[81] = job_info[78] ^ job_info[80] ^ 0x02
+
+        return job_info
+
+
+class JciHitachiCommandHE(JciHitachiCommand):
+    """Sending job command to heat exchanger.
+
+    Parameters
+    ----------
+    gateway_mac_address : str
+        Gateway mac address.
+    """
+
+    def __init__(self, gateway_mac_address):
+        super().__init__(gateway_mac_address)
+
+    def get_command(self, command, value):
+        """Get job command.
+
+        Parameters
+        ----------
+        command : str
+            Status name.
+        value : int
+            Status value.
+
+        Returns
+        -------
+        bytearray
+            Bytearray command.
+        """
+
+        job_info = self.job_info_base.copy()
+        
+        # Device type
+        job_info[77] = 14
+
+        # Command (eg. target_temp)
+        job_info[78] = 128 + JciHitachiHE.idx[command]
+
+        # Value (eg. 27)
+        job_info[80] = value
+
+        # Checksum
+        # Original algorithm:
+        # xor job_info 76~80
+        # Since byte 76(0x06), 77(device type), and 79(0x00) are constants,
+        # here is the simplified algorithm:
+        # command ^ value ^ 0x08
+        job_info[81] = job_info[78] ^ job_info[80] ^ 0x08
 
         return job_info
 
@@ -109,7 +209,7 @@ class JciHitachiStatusInterpreter:
 
     def _decode_status_number(self):
         if 6 < self.base64_bytes[0] and (self.base64_bytes[1], self.base64_bytes[2]) == (0, 8):
-            return int((self.base64_bytes[0]-4)/3)
+            return int((self.base64_bytes[0] - 4) / 3)
         else:
             return 0
 
@@ -122,7 +222,7 @@ class JciHitachiStatusInterpreter:
             status_bytes[1] = self.base64_bytes[stat_idx] & 0xffff7fff
             status_bytes[2:4] = self.base64_bytes[stat_idx + 1: stat_idx + 3]
 
-            output = int.from_bytes(status_bytes, byteorder='little') 
+            output = int.from_bytes(status_bytes, byteorder='little')
             return output
         else:
             output = util.bin_concat(0xff, max_func_number)
@@ -142,9 +242,10 @@ class JciHitachiStatusInterpreter:
         for i in range(self.status_number):
             ret = self._decode_single_status(self.status_number, i)
             idx = util.cast_bytes(ret >> 8, 1)
-            table[idx] = ret >> 0x18 + (ret >> 0x10 * 0x100) 
+            table[idx] = ret >> 0x18 + (ret >> 0x10 * 0x100)
         return table
 
+
 class JciHitachiStatus:
     idx = {}
 
@@ -163,6 +264,7 @@ class JciHitachiStatus:
 
         return dict((key, getattr(self, key)) for key in self.idx)
 
+
 class JciHitachiAC(JciHitachiStatus):
     """Data class representing air conditioner status.
 
@@ -186,7 +288,8 @@ class JciHitachiAC(JciHitachiStatus):
         'fast_op': 26,
         'energy_save': 27,
         'sound_prompt': 30,
-        'outdoor_temp': 33
+        'outdoor_temp': 33,
+        'power_kwh': 40,
     }
 
     def __init__(self, status):
@@ -194,7 +297,7 @@ class JciHitachiAC(JciHitachiStatus):
         
     @property
     def power(self):
-        """Power.
+        """Power. Controlable.
 
         Returns
         -------
@@ -214,7 +317,7 @@ class JciHitachiAC(JciHitachiStatus):
 
     @property
     def mode(self):
-        """Mode.
+        """Mode. Controlable.
 
         Returns
         -------
@@ -240,7 +343,7 @@ class JciHitachiAC(JciHitachiStatus):
 
     @property
     def air_speed(self):
-        """Air speed.
+        """Air speed. Controlable.
 
         Returns
         -------
@@ -266,7 +369,7 @@ class JciHitachiAC(JciHitachiStatus):
 
     @property
     def target_temp(self):
-        """Target temperature.
+        """Target temperature. Controlable.
 
         Returns
         -------
@@ -316,7 +419,7 @@ class JciHitachiAC(JciHitachiStatus):
 
     @property
     def sleep_timer(self):
-        """Sleep timer.
+        """Sleep timer. Controlable.
         
         Returns
         -------
@@ -329,7 +432,7 @@ class JciHitachiAC(JciHitachiStatus):
     
     @property
     def vertical_wind_swingable(self):
-        """Vertical wind swingable.
+        """Vertical wind swingable. Controlable.
 
         Returns
         -------
@@ -349,7 +452,7 @@ class JciHitachiAC(JciHitachiStatus):
 
     @property
     def vertical_wind_direction(self):
-        """Vertical wind direction.
+        """Vertical wind direction. Controlable.
 
         Returns
         -------
@@ -362,7 +465,7 @@ class JciHitachiAC(JciHitachiStatus):
 
     @property
     def horizontal_wind_direction(self):
-        """Horizontal wind direction.
+        """Horizontal wind direction. Controlable.
 
         Returns
         -------
@@ -393,7 +496,7 @@ class JciHitachiAC(JciHitachiStatus):
 
     @property
     def mold_prev(self):
-        """Mold prevention.
+        """Mold prevention. Controlable.
 
         Returns
         -------
@@ -413,7 +516,7 @@ class JciHitachiAC(JciHitachiStatus):
     
     @property
     def fast_op(self):
-        """Fast operation.
+        """Fast operation. Controlable.
 
         Returns
         -------
@@ -433,7 +536,7 @@ class JciHitachiAC(JciHitachiStatus):
     
     @property
     def energy_save(self):
-        """Energy saving.
+        """Energy saving. Controlable.
 
         Returns
         -------
@@ -453,7 +556,7 @@ class JciHitachiAC(JciHitachiStatus):
 
     @property
     def sound_prompt(self):
-        """Sound prompt.
+        """Sound prompt. Controlable.
 
         Returns
         -------
@@ -483,10 +586,25 @@ class JciHitachiAC(JciHitachiStatus):
 
         v = self._status.get(self.idx['outdoor_temp'], -1)
         return v
+    
+    @property
+    def power_kwh(self):
+        """Accumulated Kwh in a day.
+
+        Returns
+        -------
+        float
+            Kwh.
+        """
+
+        v = self._status.get(self.idx['power_kwh'], -1)
+        if v == -1:
+            return v
+        return v / 10.0
 
 
 class JciHitachiDH(JciHitachiStatus):
-    """Data class representing dehumidifier status. Not implemented.
+    """Data class representing dehumidifier status.
 
     Parameters
     ----------
@@ -501,11 +619,20 @@ class JciHitachiDH(JciHitachiStatus):
         'indoor_humidity': 7,
         'wind_swingable': 8,
         'water_full_warning': 10,
+        'clean_filter_notify': 11,
+        'air_purify_level': 13,
         'air_speed': 14,
+        'side_vent': 15,
+        'sound_control': 16,
+        'error_code': 18,
+        'mold_prev': 19,
+        'power_kwh': 29,
         'air_quality_value': 35,
         'air_quality_level': 36,
         'pm25_value': 37,
-        'odor_level': 40
+        'display_brightness': 39,
+        'odor_level': 40,
+        'air_cleaning_filter': 41
     }
 
     def __init__(self, status):
@@ -513,7 +640,7 @@ class JciHitachiDH(JciHitachiStatus):
     
     @property
     def power(self):
-        """Power.
+        """Power. Controlable.
 
         Returns
         -------
@@ -533,7 +660,7 @@ class JciHitachiDH(JciHitachiStatus):
     
     @property
     def mode(self):
-        """Mode.
+        """Mode. Controlable.
 
         Returns
         -------
@@ -568,7 +695,7 @@ class JciHitachiDH(JciHitachiStatus):
 
     @property
     def target_humidity(self):
-        """Target humidity.
+        """Target humidity. Controlable.
 
         Returns
         -------
@@ -591,10 +718,34 @@ class JciHitachiDH(JciHitachiStatus):
 
         v = self._status.get(self.idx['indoor_humidity'], -1)
         return v
-        
+    
+    @property
+    def max_humidity(self):
+        """Maximum target humidity.
+
+        Returns
+        -------
+        int
+            Relative humidity.
+        """
+
+        return 70
+
+    @property
+    def min_humidity(self):
+        """Minimum target humidity.
+
+        Returns
+        -------
+        int
+            Relative humidity.
+        """
+
+        return 40
+
     @property
     def wind_swingable(self):
-        """Wind swingable.
+        """Wind swingable. Controlable.
 
         Returns
         -------
@@ -602,7 +753,7 @@ class JciHitachiDH(JciHitachiStatus):
             One of ("unsupported", "off", "on", "unknown").
         """
 
-        v = self._status.get(self.idx['power'], -1)
+        v = self._status.get(self.idx['wind_swingable'], -1)
         if v == -1:
             return "unsupported"
         elif v == 0:
@@ -623,6 +774,83 @@ class JciHitachiDH(JciHitachiStatus):
         """
 
         v = self._status.get(self.idx['water_full_warning'], -1)
+        if v == -1:
+            return "unsupported"
+        elif v == 0:
+            return "off"  # not activated
+        elif v == 1:
+            return "on"  # activated
+        else:
+            return "unknown"
+    
+    @property
+    def clean_filter_notify(self):
+        """Clean filter notify control. Controlable.
+
+        Returns
+        -------
+        str
+            One of ("unsupported", "disabled", "enabled", "unknown").
+        """
+
+        v = self._status.get(self.idx['clean_filter_notify'], -1)
+        if v == -1:
+            return "unsupported"
+        elif v == 0:
+            return "disabled"
+        elif v == 1:
+            return "enabled"
+        else:
+            return "unknown"
+
+    @property
+    def air_purify_level(self):
+        """Air purify level. Not implemented.
+
+        Returns
+        -------
+        str
+            Not implemented.
+        """
+        return "unsupported"
+
+    @property
+    def air_speed(self):
+        """Air speed. Controlable.
+
+        Returns
+        -------
+        str
+            One of ("unsupported", "auto", "silent", "low", "moderate", "high", "unknown").
+        """
+
+        v = self._status.get(self.idx['air_speed'], -1)
+        if v == -1:
+            return "unsupported"
+        elif v == 0:
+            return "auto"
+        elif v == 1:
+            return "silent"
+        elif v == 2:
+            return "low"
+        elif v == 3:
+            return "moderate"
+        elif v == 4:
+            return "high"
+        else:
+            return "unknown"
+
+    @property
+    def side_vent(self):
+        """Side vent.
+
+        Returns
+        -------
+        str
+            One of ("unsupported", "off", "on", "unknown").
+        """
+
+        v = self._status.get(self.idx['side_vent'], -1)
         if v == -1:
             return "unsupported"
         elif v == 0:
@@ -633,15 +861,74 @@ class JciHitachiDH(JciHitachiStatus):
             return "unknown"
 
     @property
-    def air_speed(self):
-        """Air speed. Not implemented.
+    def sound_control(self):
+        """Sound control. Controlable.
 
         Returns
         -------
         str
-            Not implemented.
+            One of ("unsupported", "silent", "button", "button+waterfull", "unknown").
         """
-        pass
+
+        v = self._status.get(self.idx['sound_control'], -1)
+        if v == -1:
+            return "unsupported"
+        elif v == 0:
+            return "silent"
+        elif v == 1:
+            return "button"
+        elif v == 2:
+            return "button+waterfull"
+        else:
+            return "unknown"
+
+    @property
+    def error_code(self):
+        """Error code.
+
+        Returns
+        -------
+        int
+            Error code.
+        """
+
+        v = self._status.get(self.idx['error_code'], -1)
+        return v
+
+    @property
+    def mold_prev(self):
+        """Mold prevention. Controlable.
+
+        Returns
+        -------
+        str
+            One of ("unsupported", "off", "on", "unknown").
+        """
+
+        v = self._status.get(self.idx['mold_prev'], -1)
+        if v == -1:
+            return "unsupported"
+        elif v == 0:
+            return "off"
+        elif v == 1:
+            return "on"
+        else:
+            return "unknown"
+
+    @property
+    def power_kwh(self):
+        """Accumulated Kwh in a day.
+
+        Returns
+        -------
+        float
+            Kwh.
+        """
+
+        v = self._status.get(self.idx['power_kwh'], -1)
+        if v == -1:
+            return v
+        return v / 10.0
 
     @property
     def air_quality_value(self):
@@ -652,7 +939,7 @@ class JciHitachiDH(JciHitachiStatus):
         int
             Not implemented.
         """
-        pass
+        return -1
 
     @property
     def air_quality_level(self):
@@ -663,29 +950,84 @@ class JciHitachiDH(JciHitachiStatus):
         str
             Not implemented.
         """
-        pass
+        return "unsupported"
     
     @property
     def pm25_value(self):
-        """PM2.5 value. Not implemented.
+        """PM2.5 value.
 
         Returns
         -------
         int
-            Not implemented.
+            PM2.5 value.
         """
-        pass
+
+        v = self._status.get(self.idx['pm25_value'], -1)
+        return v
     
     @property
-    def odor_level(self):
-        """Odor level. Not implemented.
+    def display_brightness(self):
+        """Display brightness. Controlable.
 
         Returns
         -------
         str
-            Not implemented.
+            One of ("unsupported", "bright", "dark", "off", "all_off" "unknown").
         """
-        pass
+        v = self._status.get(self.idx['display_brightness'], -1)
+        if v == -1:
+            return "unsupported"
+        elif v == 0:
+            return "bright"
+        elif v == 1:
+            return "dark"
+        elif v == 2:
+            return "off"
+        elif v == 3:
+            return "all_off"
+        else:
+            return "unknown"
+
+    @property
+    def odor_level(self):
+        """Odor level.
+
+        Returns
+        -------
+        str
+            One of ("unsupported", "low", "middle", "high", "unknown").
+        """
+        v = self._status.get(self.idx['odor_level'], -1)
+        if v == -1:
+            return "unsupported"
+        elif v == 0:
+            return "low"
+        elif v == 1:
+            return "middle"
+        elif v == 2:
+            return "high"
+        else:
+            return "unknown"
+    
+    @property
+    def air_cleaning_filter(self):
+        """Air cleaning filter setting.
+
+        Returns
+        -------
+        str
+            One of ("unsupported", "disabled", "enabled", "unknown").
+        """
+
+        v = self._status.get(self.idx['air_cleaning_filter'], -1)
+        if v == -1:
+            return "unsupported"
+        elif v == 0:
+            return "disabled"
+        elif v == 1:
+            return "enabled"
+        else:
+            return "unknown"
 
 
 class JciHitachiHE(JciHitachiStatus):
@@ -697,5 +1039,7 @@ class JciHitachiHE(JciHitachiStatus):
         Status retrieved from JciHitachiStatusInterpreter.decode_status().
     """
 
+    idx = {}
+
     def __init__(self, status):
         super().__init__(status)
